import java.io.*;
import java.text.*;
import java.util.*;

public class JType {
	final static String sAppName=JType.class.getSimpleName();
	boolean bVerbose=false, bCheckAll=false, bFound=false, bLong=false;
	SimpleDateFormat sdf=new SimpleDateFormat("dd.MM.yyyy HH:mm:ss");
	String[] sPathList, sPossibleExtList = {
		"com","exe","bat","cmd","dll"
	};

	public JType(String[] args) throws Exception {
		if (args.length < 1) usage();
		String sPathSep=System.getProperty("path.separator");
		String sFileSep=System.getProperty("file.separator");
		String sPathName=System.getenv("PATH");
		if (sPathName==null || sPathName.isEmpty())
			throw new Exception ("FATAL: Path variable is empty!");
		sPathList=sPathName.split(sPathSep);
		for (String s: args) {
			if (s.startsWith("-") && s.length() > 1) {
				for (int i=1; i<s.length(); i++) {
					switch(s.toUpperCase().charAt(i)) {
					case 'A': bCheckAll=true; break;
					case 'L': bLong=true; break;
					case 'V': bVerbose=true; break;
					}
				}
				continue;
			}
			File f=new File("."+sFileSep+s);
			if (f.exists()) {
				System.out.printf("%s is %s\n", s, "."+sFileSep+s);
				bFound=true;
				if (!bCheckAll) System.exit(0);
			}
			for (String sp: sPathList) {
				if (!sp.endsWith(sFileSep)) sp+=sFileSep;
				if (bVerbose) System.out.printf("Checking \"%s\"\n", sp+s);
				f=new File(sp+s);
				if (f.exists()) {
					printFileInfo(f);
					bFound=true;
					if (!bCheckAll) break;
				} else { // check the possible extensions
					for (String se: sPossibleExtList) {
						f=new File(sp+s+"."+se);
						if (f.exists()) {
							printFileInfo(f);
							bFound=true;
							if (!bCheckAll) break;
						}
					}
				}
			}
			if (!bFound) {
				System.err.printf("File %s NOT found!\n", s);
			}
		}
	}

	private void usage() {
		System.err.printf("usage: %s name ...\n", sAppName);
		System.exit(1);
	}

	public void printFileInfo(File f) {
		System.out.printf("%s is %s\n", f.getName(), f.getAbsolutePath());
		if (bLong) {
			System.out.printf("%s %s %s Byte(s)\n", f.getName(), sdf.format(new Date(f.lastModified())), sPrintDottedNumber(f.length()));
		}
	}

	public String sPrintDottedNumber(long lNumber) {
		StringBuffer sb= new StringBuffer("   .   .   .   ");
		int[] ist = { 14,13,12,10,9,8,6,5,4,2,1,0 };
		for (int i=0;;i++) {
			sb.setCharAt(ist[i],(char)('0'+(lNumber % 10)));
			if ((lNumber/=10)==0) {
				for (int j=ist[i]-1;j>=0;j--) sb.setCharAt(j, ' ');
				break;
			}
		}
		return sb.toString();
	}

	public static void main(String[] args) {
		try {
			new JType(args);
		} catch (Exception e) {
			e.printStackTrace();
			System.exit(1);
		}
	}
}
